# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.data_api import DataApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.data_api.DataApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_latest_by_uuid(self):
        """Test case for get_latest_by_uuid

        Retrieve latest values and analytics for a single Resource  # noqa: E501
        """
        pass

    def test_get_summary_by_uuid(self):
        """Test case for get_summary_by_uuid

        Retrieve the data summary for a single Resource  # noqa: E501
        """
        pass

    def test_publish_data(self):
        """Test case for publish_data

        Publish data to a single or multiple Resources  # noqa: E501
        """
        pass

    def test_query_latest(self):
        """Test case for query_latest

        Retrieve the latest values received for multiple Resources  # noqa: E501
        """
        pass

    def test_query_summary(self):
        """Test case for query_summary

        Retrieve the data summaries of mutliple Resource  # noqa: E501
        """
        pass

    def test_query_time_range(self):
        """Test case for query_time_range

        Retrieve analytics for a single Resource  # noqa: E501
        """
        pass

    def test_query_time_range_raw(self):
        """Test case for query_time_range_raw

        Retrieve the raw data received for a single Resource  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
